==> supplier-center-api-2.1.33-sources.jar: cn/com/duiba/supplier/center/api/params/GoodsBatchDeliveryRequest.java <==
package cn.com.duiba.supplier.center.api.params;

import java.io.Serializable;

/**
 * @program: supplier-center
 * @description: 商品批量发货mq请求
 * @author: Simba
 * @create: 2018-12-24 20:43
 **/
public class GoodsBatchDeliveryRequest implements Serializable {

    private static final long serialVersionUID = -5069069752625090432L;


    private Long supplyOrderNum;

    /** 采购子订单 */
    private Long supplyProductOrderNum;

    private Long ordersItemId;

    private Long supplierId;

    private String expressCompanyName;

    private String expressCompanyNo;

    public Long getSupplyOrderNum() {
        return supplyOrderNum;
    }

    public void setSupplyOrderNum(Long supplyOrderNum) {
        this.supplyOrderNum = supplyOrderNum;
    }

    public Long getSupplyProductOrderNum() {
        return supplyProductOrderNum;
    }

    public void setSupplyProductOrderNum(Long supplyProductOrderNum) {
        this.supplyProductOrderNum = supplyProductOrderNum;
    }

    public Long getOrdersItemId() {
        return ordersItemId;
    }

    public void setOrdersItemId(Long ordersItemId) {
        this.ordersItemId = ordersItemId;
    }

    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }

    public String getExpressCompanyName() {
        return expressCompanyName;
    }

    public void setExpressCompanyName(String expressCompanyName) {
        this.expressCompanyName = expressCompanyName;
    }

    public String getExpressCompanyNo() {
        return expressCompanyNo;
    }

    public void setExpressCompanyNo(String expressCompanyNo) {
        this.expressCompanyNo = expressCompanyNo;
    }
}

==> supplier-center-api-2.1.55-20251107.093928-1-sources.jar: cn/com/duiba/supplier/center/api/params/GoodsBatchDeliveryRequest.java <==
package cn.com.duiba.supplier.center.api.params;

import java.io.Serializable;

/**
 * @program: supplier-center
 * @description: 商品批量发货mq请求
 * @author: Simba
 * @create: 2018-12-24 20:43
 **/
public class GoodsBatchDeliveryRequest implements Serializable {

    private static final long serialVersionUID = -5069069752625090432L;


    private Long supplyOrderNum;

    /** 采购子订单 */
    private Long supplyProductOrderNum;

    private Long ordersItemId;

    private Long supplierId;

    private String expressCompanyName;

    private String expressCompanyNo;

    /**
     * 发货数量
     */
    private Long deliveryQuantity;

    public Long getSupplyOrderNum() {
        return supplyOrderNum;
    }

    public void setSupplyOrderNum(Long supplyOrderNum) {
        this.supplyOrderNum = supplyOrderNum;
    }

    public Long getSupplyProductOrderNum() {
        return supplyProductOrderNum;
    }

    public void setSupplyProductOrderNum(Long supplyProductOrderNum) {
        this.supplyProductOrderNum = supplyProductOrderNum;
    }

    public Long getOrdersItemId() {
        return ordersItemId;
    }

    public void setOrdersItemId(Long ordersItemId) {
        this.ordersItemId = ordersItemId;
    }

    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }

    public String getExpressCompanyName() {
        return expressCompanyName;
    }

    public void setExpressCompanyName(String expressCompanyName) {
        this.expressCompanyName = expressCompanyName;
    }

    public String getExpressCompanyNo() {
        return expressCompanyNo;
    }

    public void setExpressCompanyNo(String expressCompanyNo) {
        this.expressCompanyNo = expressCompanyNo;
    }

    public Long getDeliveryQuantity() {
        return deliveryQuantity;
    }

    public void setDeliveryQuantity(Long deliveryQuantity) {
        this.deliveryQuantity = deliveryQuantity;
    }
}
